@@ -456,7 +456,7 @@ static void push_file_context(struct lexer_state *ls)
 static void pop_file_context(struct lexer_state *ls)
 {
 #ifdef AUDIT
-	if (ls_depth <= 0) ouch("prepare to meet thy creator");
+	if (!ls_depth) ouch("prepare to meet thy creator");
 #endif
 	close_input(ls);
 	restore_lexer_state(ls, &(ls_stack[-- ls_depth].ls));
@@ -1053,6 +1053,7 @@ static int handle_if(struct lexer_state *ls)
 	freemem(tf.t);
 	if (tf1.nt == 0) {
 		error(l, "void condition (after expansion) for a #if/#elif");
+                freemem(tf1.t);
 		return -1;
 	}
 
@@ -1146,6 +1147,7 @@ static int handle_if(struct lexer_state *ls)
 	freemem(tf1.t);
 	if (tf2.nt == 0) {
 		error(l, "void condition (after expansion) for a #if/#elif");
+                freemem(tf2.t);
 		return -1;
 	}
 
@@ -1174,6 +1176,7 @@ static int handle_if(struct lexer_state *ls)
 
 	if (tf3.nt == 0) {
 		error(l, "void condition (after expansion) for a #if/#elif");
+                freemem(tf3.t);
 		return -1;
 	}
 	eval_line = l;
@@ -1443,7 +1446,7 @@ static int handle_line(struct lexer_state *ls, unsigned long flags)
 	char *fname;
 	long l = ls->line;
 	struct token_fifo tf, tf2, *save_tf;
-	size_t nl, j;
+	size_t j;
 	unsigned long z;
 
 	tf.art = tf.nt = 0;
@@ -1509,6 +1512,7 @@ static int handle_line(struct lexer_state *ls, unsigned long flags)
 	ls->oline = ls->line = z;
 	if ((++ tf2.art) < tf2.nt) {
 		size_t i;
+		size_t nl;
 
 		for (i = tf2.art; i < tf2.nt && ttMWS(tf2.t[i].type); i ++);
 		if (i < tf2.nt) {
@@ -1650,6 +1654,7 @@ static void handle_pragma(struct lexer_state *ls)
 	}
 	if (tf.nt == 0) {
 		/* void pragma are silently ignored */
+                freemem(tf.t);
 		return;
 	}
 	buf = (compress_token_list(&tf)).t;
@@ -1697,7 +1702,6 @@ static int handle_cpp(struct lexer_state *ls, int sharp_type)
 	unsigned long save_flags = ls->flags;
 	int ret = 0;
 
-	save_flags = ls->flags;
 	ls->flags |= LEXER;
 	while (!next_token(ls)) {
 		int t = ls->ctok->type;
@@ -1989,7 +1993,6 @@ handle_exit2:
 	return ret;
 too_many_if:
 	error(l, "too many levels of conditional inclusion (max 63)");
-	ret = 1;
 	goto handle_warp;
 #undef condfset
 #undef condfclr
@@ -2201,26 +2204,8 @@ void init_tables(int with_assertions)
 #endif
 	time(&t);
 	ct = localtime(&t);
-#ifndef STRFTIME
-	/* we have a quite old compiler, that does not know the
-	   (standard since 1990) strftime() function. */
-	{
-		char *c = asctime(ct);
-
-		compile_time[0] = '"';
-		mmv(compile_time + 1, c + 11, 8);
-		compile_time[9] = '"';
-		compile_time[10] = 0;
-		compile_date[0] = '"';
-		mmv(compile_date + 1, c + 4, 7);
-		mmv(compile_date + 8, c + 20, 4);
-		compile_date[12] = '"';
-		compile_date[13] = 0;
-	}
-#else
 	strftime(compile_time, 12, "\"%H:%M:%S\"", ct);
 	strftime(compile_date, 24, "\"%b %d %Y\"", ct);
-#endif
 	init_macros();
 	if (with_assertions) init_assertions();
 	init_found_files();
