@@ -521,8 +521,6 @@ define_end:
 		if (mval.nt == 0) freemem(mval.t);
 	}
 	if (mval.nt != 0) {
-		size_t i;
-
 		/* some checks about the macro */
 		if (mval.t[0].type == DSHARP
 			|| mval.t[0].type == DIG_DSHARP
@@ -532,19 +530,22 @@ define_end:
 				"nor end a macro");
 			goto define_error;
 		}
-		if (m->narg >= 0) for (i = 0; i < mval.nt; i ++)
-			if ((mval.t[i].type == SHARP
-				|| mval.t[i].type == DIG_SHARP) &&
-				(i == (mval.nt - 1)
-				|| (ttMWS(mval.t[i + 1].type) &&
-				    (i == mval.nt - 2
-				     || mval.t[i + 2].type != MACROARG))
-				|| (!ttMWS(mval.t[i + 1].type)
-				     && mval.t[i + 1].type != MACROARG))) {
-				error(l, "operator '#' not followed "
-					"by a macro argument");
-				goto define_error;
-			}
+		if (m->narg >= 0) {
+			size_t i;
+			for (i = 0; i < mval.nt; i ++)
+				if ((mval.t[i].type == SHARP
+					|| mval.t[i].type == DIG_SHARP) &&
+					(i == (mval.nt - 1)
+					|| (ttMWS(mval.t[i + 1].type) &&
+					    (i == mval.nt - 2
+					     || mval.t[i + 2].type != MACROARG))
+					|| (!ttMWS(mval.t[i + 1].type)
+					     && mval.t[i + 1].type != MACROARG))) {
+					error(l, "operator '#' not followed "
+						"by a macro argument");
+					goto define_error;
+				}
+		}
 	}
 	{
 		size_t i, l;
